@@ -123,12 +123,14 @@ setMethod("dots", signature(x="SpatVector"),
 	if (is.null(out$leg$density)) {
 		for (i in seq_along(g)) {
 			for (j in seq_along(g[[i]])) {
+				if (any(is.na(g[[i]][[j]]))) next
 				graphics::polypath(g[[i]][[j]][[1]], g[[i]][[j]][[2]], col=out$main_cols[i], rule = "evenodd", border=out$leg$border[i], lwd=out$leg$lwd[i], lty=out$leg$lty[i], ...)
 			}
 		}
 	} else {
 		for (i in 1:length(g)) {
 			for (j in seq_along(g[[i]])) {
+				if (any(is.na(g[[i]][[j]]))) next
 				graphics::polygon(g[[i]][[j]][[1]], g[[i]][[j]][[2]], col=out$main_cols[i], density=out$leg$density[i], angle=out$leg$angle[i], border=NA, lwd=out$leg$lwd[i], lty=out$leg$lty[i], ...)
 				graphics::polypath(g[[i]][[j]][[1]], g[[i]][[j]][[2]], col=NA, rule="evenodd", border=out$leg$border[i], lwd=out$leg$lwd[i], lty=out$leg$lty[i], ...)
 			}
@@ -440,6 +442,9 @@ setMethod("dots", signature(x="SpatVector"),
 	}
 	
 	e <- as.vector(ext(x))
+	if (any(is.na(e))) {
+		error("plot", "SpatVector has no valid geometries")
+	}
 	if (e[1] == e[2]) {
 		e[1] = e[1] - 0.5
 		e[2] = e[2] + 0.5
@@ -630,8 +635,8 @@ setMethod("dots", signature(x="SpatVector"),
 
 
 setMethod("plot", signature(x="SpatVector", y="character"),
-	function(x, y, col=NULL, type=NULL, mar=NULL, add=FALSE, legend=!add, axes=!add,
-	main="", buffer=TRUE, background=NULL, grid=FALSE, ext=NULL, 
+	function(x, y, col=NULL, type=NULL, mar=NULL, add=FALSE, legend=TRUE, axes=!add,
+	main, buffer=TRUE, background=NULL, grid=FALSE, ext=NULL, 
 	sort=TRUE, decreasing=FALSE, plg=list(), pax=list(), nr, nc, colNA=NA, 
 	alpha=NULL, box=axes, clip=TRUE, ...) {
 
@@ -657,9 +662,14 @@ setMethod("plot", signature(x="SpatVector", y="character"),
 			legend <- TRUE
 		}
 
+
 		for (i in 1:length(y)) {
 			if (length(y) > 1) {
-				main <- rep_len(main, length(y))
+				if (missing("main")) {
+					main <- names(x)
+				} else {
+					main <- rep_len(main, length(y))
+				}
 				newrow <- (nrnc[2] == 1) | ((i %% nrnc[2]) == 1)
 				lastrow <- i > (prod(nrnc) - nrnc[2])
 				if (lastrow) {
@@ -673,7 +683,10 @@ setMethod("plot", signature(x="SpatVector", y="character"),
 				} else {
 					pax$side <- 0
 				}
+			} else if (missing("main")) {
+				main <- ""
 			}
+
 			if (missing(col)) col <- NULL
 
 			out <- .prep.vect.data(x, y[i], type=type, cols=col, mar=mar, plg=plg, pax=pax, legend=isTRUE(legend), add=add, axes=axes, main=main[i], buffer=buffer, background=background, grid=grid, ext=ext, sort=sort, decreasing=decreasing, colNA=colNA, alpha=alpha, box=box, clip=clip, leg_i=i, ...)
