@@ -1,8 +1,8 @@
 
 setMethod("update", signature(object="SpatRaster"),
 	function(object, names=FALSE, crs=FALSE, extent=FALSE) {
-		opt <- terra:::spatOptions()
-		ok = object@ptr$update_meta(names, crs, extent, opt)
+		opt <- spatOptions()
+		ok <- object@ptr$update_meta(names, crs, extent, opt)
 		messages(object, "update")
 		invisible(object)
 	}
